﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Benner.Corporativo.TestesInterface.ArquivosDeDados.Usuarios;
using Benner.Tecnologia.Wes.UITests;
using Benner.Tecnologia.Wes.UITests.Atributos;
using NUnit.Framework;
using OpenQA.Selenium;

namespace Benner.Corporativo.TestesInterface.Mapeamento.Usuarios
{
    public class FormUsuarios : GenericForm
    {
        public const string casoTeste01 = "Teste de Inclusão de Usuário";
        public const string idTest01 = "01_CadastroUsuario";

        public const string casoTeste02 = "Teste de Exclusão de Usuário";
        public const string idTest02 = "02_ExclusaoUsuario";

        [Campo("NOME")]
        public CampoTexto Nome { get; set; }

        [Campo("EMAIL")]
        public CampoTexto Email { get; set; }

        [Campo("APELIDO")]
        public CampoTexto Apelido { get; set; }

        [Campo("SENHA")]
        public CampoTexto SenhaUsuario { get; set; }

        [Campo("GRUPO")]
        public CampoTabela Grupo { get; set; }

        public FormUsuarios(IWebDriver browser, IWebElement widget, string id) : base(browser, widget, id) { }

        public override void PreencherCampos<Dados>(Dados dadosClasse)
        {
            DadosUsuarios dados = dadosClasse as DadosUsuarios;

            Nome.Preencher(dados.Nome);
            Email.Preencher(dados.Email);
            Apelido.Preencher(dados.Apelido);
            SenhaUsuario.Preencher(dados.SenhaUsuario);
            IWebElement repetirSenha = this.Elemento.EncontrarElemento(By.Id("ctl00_Main_USUARIO_PageControl_GENERICO_GENERICO__CONFIRMPASSWORDCONTROL"));
            repetirSenha.SendKeys(dados.SenhaUsuario);
            Grupo.Preencher(dados.Grupo);
        }

        public override void ValidarCampos<Dados>(Dados dadosClasse)
        {
            DadosUsuarios dados = dadosClasse as DadosUsuarios;

            Assert.IsTrue(Nome.Validar(dados.Nome));
            Assert.IsTrue(Email.Validar(dados.Email));
            Assert.IsTrue(Apelido.Validar(dados.Apelido));
            Assert.IsTrue(SenhaUsuario.Validar(dados.SenhaUsuario));
            IWebElement repetirSenha = this.Elemento.EncontrarElemento(By.Id("ctl00_Main_USUARIO_PageControl_GENERICO_GENERICO__CONFIRMPASSWORDCONTROL"));
            Assert.IsTrue(repetirSenha.Text == dados.SenhaUsuario);
            Assert.IsTrue(Grupo.Validar(dados.Grupo));
        }

        public override void LimparCampos()
        {
            Nome.Limpar();
            Email.Limpar();
            Apelido.Limpar();
            SenhaUsuario.Limpar();
            Grupo.Limpar();
        }
    }
}
